using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace wispro.sp.web.Models
{
    public class ProjectInfo
    {
        public string CaseNo { get; set; }
        public string CaseName { get; set; }

        public string DoItem { get; set; }

        public string ResponseMan { get; set; }

        public List<string> DoPerson { get; set; }
    }

    public class ProjectPoint
    {
        public string person { get; set; }

        public string doItem { get; set; }

        public string DoItemCoefficient { get; set; }

        public double Point { get; set; }
    }

    public class Task
    {
        public int Id { get; set; }
        public string Name { get; set; }

        public string Creater { get; set; }

        public string ResponseMan { get; set; }

        public string UIUrl { get; set; }

        public List<TaskHandleInfo> Handles { get; set; }

        public string Type { get; set; }

        public DateTime? LimiteDate { get; set; }

        public ProjectInfo ProjectInfo { get; set; }

        public string State { get; set; }

        public DateTime? FinishedTime { get; set; }

        public DateTime CreateTime { get; set; } = DateTime.Now;

        public List<InputField> InputFields { get; set; }
    }

    public class TaskHandleInfo
    {
        public string Name { get; set; }

        public string UIUrl { get; set; }
    }

    public class ProjectMessage
    {
        public string From { get; set; }

        public List<MsgReadInfo> To { get; set; }

        public string MessageInfo { get; set; }

        public List<Task> Tasks { get; set; }

        public string Type { get; set; }

        //public List<ProjectInfo> ProjectInfos { get; set; }
    }

    public class MsgReadInfo
    {
        public string Reciever { get; set; }

        public bool isReaded { get; set; }

        public DateTime? ReadTime { get; set; }
    }
}
